function t = TGTSf(f,mpp,mns,mxs)
%
% TGTSf: Tom's Gradient Topo Sketch returns topographical labels on an image
%        function.
% On input:
%     f:     image function (2D)
%   mpp:     meters per pixel
%   mns:     minimum in absolute scale in meters for feature detection
%   mxs:     minimum in absolute scale in meters for feature detection
% On output:
%   t:       0   unlabeled
%            1   flat
%            2   hillside
%            4   ridge
%            8   ravine
% Calling sequence:
%     t = TGTS(f,mpp,mns,mxs)
%

t = 0*f;
ff = TGflat(f,3*mns);
t = ff<0.1;
fh = TGhills(f,3*mns);
t = t + (2*(fh>0.8));
frid = TGrid(f,fh,mns);
t = t + (4*(frid>0));
frav = TGrav(f,fh,mns);
t = t + (8*(frav>0));
